Arguments
x
x is matrix of order n x p where n is number of observations and p is number of predictor variables. Rows should represent observations and columns should represent predictor variables.
y
y is a vector of response variable of order n x 1.
k
Number of folds for cross validation. Default is k=5.
nlambda
Number of lambda values to be used for cross validation. Default is nlambda=50.
tau
Elastic net parameter, $0 \le \tau \le 1$ in elastic net penalty $\lambda{\tau|\beta|_1+(1-\tau)|\beta|_2^2}$. Default tau=1 corresponds to LASSO penalty.
plot
if TRUE, produces a plot of cross validated prediction mean squared errors against lambda. Default is TRUE.
errorbars
If TRUE, error bars are drawn in the plot. Default is TRUE.